import type { BroadcastEvent, WidgetData, WidgetParams } from '@widget-js/core';
import type { ComputedRef, Ref, UnwrapRef } from 'vue';
import type { UseDefaultOverlapContextMenuOption } from '../composition';
import type { UseWidgetParamsOption } from '../composition/useWidgetParams';
export interface UseWidgetOption<T extends WidgetData> extends UseWidgetParamsOption {
    onDataLoaded?: (data: T | undefined, initialLoad: boolean) => void;
    defaultData?: UnwrapRef<T>;
    /**
     * 是否忽略组件id，只通过组件名获取数据
     */
    loadDataByWidgetName?: boolean;
    /**
     * 组件id，如果不传默认使用WidgetParams里的id
     */
    widgetId?: string;
    /**
     * 组件名，如果不传默认使用WidgetParams里的name
     */
    widgetName?: string;
    defaultOverlapMenu?: boolean | UseDefaultOverlapContextMenuOption;
    useBroadcastEvent?: string[];
    onBroadcastEvent?: (broadcastEvent: BroadcastEvent) => void;
}
export interface UseWidgetReturn<T extends WidgetData> {
    widgetParams: WidgetParams;
    widgetData: Ref<UnwrapRef<T>>;
    dataLoaded: Ref<boolean>;
    sizeStyle: ComputedRef<{
        width: string;
        height: string;
    }>;
    save: (saveOptions?: SaveOptions) => Promise<void>;
}
export interface SaveOptions {
    closeWindow?: boolean;
    sendBroadcast?: boolean;
}
export declare function useWidget<T extends WidgetData>(Type: {
    new (name: string, id?: string): T;
}, option?: UseWidgetOption<T>): UseWidgetReturn<T>;
export declare function useWidgetScale(width: number, height: number, widgetWidth: number, widgetHeight: number): number;
//# sourceMappingURL=useWidget.d.ts.map